@@ -30,7 +30,7 @@ namespace Gwenview {
 class ImageView;
 
 class BCGDialog : public KDialogBase {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	BCGDialog(ImageView*);
