@@ -1,4 +1,3 @@
-// vim: set tabstop=4 shiftwidth=4 noexpandtab:
 /*
 Gwenview - A simple image viewer for TDE
 Copyright 2000-2006 Aurelien Gateau
@@ -125,10 +124,10 @@ Document::Document(TQObject* parent)
 		static Gwenview::XCursorFormatType sXCursorFormatType;
 	}
 
-	connect( this, TQT_SIGNAL( loading()),
-		this, TQT_SLOT( slotLoading()));
-	connect( this, TQT_SIGNAL( loaded(const KURL&)),
-		this, TQT_SLOT( slotLoaded()));
+	connect( this, TQ_SIGNAL( loading()),
+		this, TQ_SLOT( slotLoading()));
+	connect( this, TQ_SIGNAL( loaded(const KURL&)),
+		this, TQ_SLOT( slotLoaded()));
 }
 
 
@@ -197,8 +196,8 @@ void Document::setURL(const KURL& paramURL) {
 	d->mURL = localURL; // this may be fixed after stat() is complete, but set at least something
 	d->mStatJob = TDEIO::stat( localURL, !localURL.isLocalFile() );
 	d->mStatJob->setWindow(TDEApplication::kApplication()->mainWidget());
-	connect( d->mStatJob, TQT_SIGNAL( result (TDEIO::Job *) ),
-	   this, TQT_SLOT( slotStatResult (TDEIO::Job *) ) );
+	connect( d->mStatJob, TQ_SIGNAL( result (TDEIO::Job *) ),
+	   this, TQ_SLOT( slotStatResult (TDEIO::Job *) ) );
 }
 
 
@@ -561,12 +560,12 @@ void Document::switchToImpl(DocumentImpl* impl) {
 	delete d->mImpl;
 	d->mImpl=impl;
 
-	connect(d->mImpl, TQT_SIGNAL(finished(bool)),
-		this, TQT_SLOT(slotFinished(bool)) );
-	connect(d->mImpl, TQT_SIGNAL(sizeUpdated()),
-		this, TQT_SIGNAL(sizeUpdated()) );
-	connect(d->mImpl, TQT_SIGNAL(rectUpdated(const TQRect&)),
-		this, TQT_SIGNAL(rectUpdated(const TQRect&)) );
+	connect(d->mImpl, TQ_SIGNAL(finished(bool)),
+		this, TQ_SLOT(slotFinished(bool)) );
+	connect(d->mImpl, TQ_SIGNAL(sizeUpdated()),
+		this, TQ_SIGNAL(sizeUpdated()) );
+	connect(d->mImpl, TQ_SIGNAL(rectUpdated(const TQRect&)),
+		this, TQ_SIGNAL(rectUpdated(const TQRect&)) );
 	d->mImpl->init();
 }
 
