@@ -34,9 +34,15 @@ public:
 	
 	KFileItem* shownFileItem() const { return mShownFileItem; }
 	virtual void setShownFileItem(KFileItem* fileItem) { mShownFileItem=fileItem; }
-	
+
 	virtual void updateFromSettings() {}
 
+	using KFileView::updateView;
+	void updateView(const KFileItem* fileItem) override {
+		updateView(fileItem, false);
+	}
+	virtual void updateView(const KFileItem* fileItem, bool metaDataOnly) = 0;
+
 protected:
 	KFileItem* mShownFileItem;
 };
