@@ -27,7 +27,7 @@ namespace Gwenview {
 
 class ThreadGate : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	static ThreadGate* instance();
