@@ -1,4 +1,3 @@
-// vim: set tabstop=4 shiftwidth=4 noexpandtab:
 /*
 Gwenview - A simple image viewer for TDE
 Copyright 2000-2006 Aurélien Gâteau
@@ -26,17 +25,22 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <tdefilemetainfo.h>
 #include <tdeglobal.h>
 #include <tdelocale.h>
-	
+
+// Local
+#include "fileviewconfig.h"
+
 namespace Gwenview {
 namespace TimeUtils {
 
 time_t getTime(const KFileItem* item) {
-	const KFileMetaInfo& info = item->metaInfo();
-	if (info.isValid()) {
-		TQVariant value = info.value("Date/time");
-		TQDateTime dt = value.toDateTime();
-		if (dt.isValid()) {
-			return dt.toTime_t();
+
+	if (FileViewConfig::loadMetadata()) {
+		const KFileMetaInfo& info = item->metaInfo(/*autogen=*/false);
+		if (info.isValid()) {
+			TQDateTime dt = info.value("Date/time").toDateTime();
+			if (dt.isValid()) {
+				return dt.toTime_t();
+			}
 		}
 	}
 	return item->time(TDEIO::UDS_MODIFICATION_TIME);
